#
# spec file for package x11perf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           x11perf
Version:        1.7.0
Release:        1.3
Summary:        Utility to test X11 server performance
License:        HPND
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/test/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xmuu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xrender)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
The x11perf program runs one or more performance tests and reports how
fast an X server can execute the tests.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/x11perf
%{_bindir}/x11perfcomp
%{_datadir}/X11/x11perfcomp/
%{_mandir}/man1/Xmark.1%{?ext_man}
%{_mandir}/man1/x11perf.1%{?ext_man}
%{_mandir}/man1/x11perfcomp.1%{?ext_man}
%ifnarch %ix86
%dir %{_datadir}/X11
%endif

%changelog
* Fri Aug  2 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.7.0
  * This release adds support for the -version option, splits up the output
    of -help into several subsections ("-help [options|tests|all]"), and
    adds several new tests, which are included under the -v1.7 option:
  - tileftext              Char in 80-char line tiled (6x13)
  - putimagexybitmap10     PutImage XYBitmap 10x10 square
  - putimagexybitmap100    PutImage XYBitmap 100x100 square
  - putimagexybitmap500    PutImage XYBitmap 500x500 square
  - shmputxybitmap10       ShmPutImage XYBitmap 10x10 square
  - shmputxybitmap100      ShmPutImage XYBitmap 100x100 square
  - shmputxybitmap500      ShmPutImage XYBitmap 500x500 square
* Mon Oct 31 2022 Stefan Dirsch <sndirsch@suse.com>
- fixed URL for tarball in specfile
* Sat Oct 29 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.6.2
  * tests: Skip trapezoids for unsupported XRender formats
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Variable scope reductions as recommended by cppcheck
  * Stop casting return value of malloc() and calloc()
* Wed May 12 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file:
  * move license to licensedir
* Fri Mar 22 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.6.1
  * This is a minor maintainance and bug fix release.
* Fri Apr 24 2015 sndirsch@suse.com
- Update to version 1.6.0:
  * This release adds one new general option:
  - pause <s>                pause for <s> seconds between each run
    and several new test options:
  - crgb10text                Char in 80-char rgb core line (Charter 10)
  - crgb24text                Char in 30-char rgb core line (Charter 24)
  - crgbftext                 Char in 80-char rgb core line (Courier 12)
  - magpixwin10               Scale 5x5 from pixmap to 10x10 window
  - magpixwin100              Scale 50x50 from pixmap to 100x100 window
  - magpixwin500              Scale 250x250 from pixmap to 500x500 window
  - minpixwin10               Scale 10x10 from pixmap to 5x5 window
  - minpixwin100              Scale 100x100 from pixmap to 5x5 window
  - minpixwin500              Scale 500x500 from pixmap to 250x250 window
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to HPND in specfile
* Sun Apr 15 2012 dimstar@opensuse.org
- Update to version 1.5.4:
  + Minor bug fixes
  + Build system fixes
- Changes from version 1.5.3:
  + Avoid "rep" calculation overflow.
  + Clamp test time to positive values.
  + Bugs fixed: fdo#31640.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split x11perf from xorg-x11. Initial version: 1.5.2.
